@@ -17,19 +17,21 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __TERMINAL_DBUS_H__
-#define __TERMINAL_DBUS_H__
+#ifndef TERMINAL_GDBUS_H
+#define TERMINAL_GDBUS_H
 
-#include <terminal/terminal-app.h>
+#include "terminal-app.h"
 
 G_BEGIN_DECLS
 
-gboolean  terminal_gdbus_register_service  (TerminalApp  *app,
-                                            GError      **error);
-gboolean  terminal_gdbus_invoke_launch     (gint          argc,
-                                            gchar       **argv,
-                                            GError      **error);
+gboolean
+terminal_gdbus_register_service (TerminalApp *app,
+                                 GError **error);
+gboolean
+terminal_gdbus_invoke_launch (gint argc,
+                              gchar **argv,
+                              GError **error);
 
 G_END_DECLS
 
-#endif /* !__TERMINAL_DBUS_H__ */
+#endif /* !TERMINAL_GDBUS_H */
